## _phenopackets_

#### Examples

* <https://progenetix.org/cgi/bycon/services/phenopackets.py?datasetIds=progenetix&assemblyId=GRCh38&includeDatasetResponses=ALL&referenceName=17&variantType=DEL&filterLogic=AND&start=4999999&start=7676592&end=7669607&end=10000000&filters=cellosaurus&debug=1>
* https://progenetix.org/services/phenopackets?do=phenopackets&accessid=b6340d0f-1c55-42fc-9372-0f7a4f4f5581&variantsaccessid=20b15bd5-2acf-4f36-b143-c1dc24f5191f&debug=1
  - this example obviously only works with real `assessid` and `variantsaccessid` parameters

